<?php

/*
Plugin Name: WordPress HelpCenter 
Plugin URI: http://wphelpcenter.com 
Description: Easily contact WordPress HelpCenter for troubleshooting, questions, development, customizations... anything you need for WordPress. 
Version: 1.2 
Author: Crowd Favorite
Author URI: http://crowdfavorite.com
*/

// ini_set('display_errors', '1'); ini_set('error_reporting', E_ALL);

if (!defined('WPHC_LOADED')) : // don't load twice

define('WPHC_LOADED', true);

if (!defined('PLUGINDIR')) {
	define('PLUGINDIR','wp-content/plugins');
}

define('WPHC_EMAIL', 'help@wphelpcenter.com');
define('WPHC_PHONE', '(303) 395-1346');
define('WPHC_REFERENCE_ID', '');

load_plugin_textdomain('wphelpcenter');

function wphc_reference_id() {
	if ($ref_id = get_option('wphc_reference_id')) {
		return $ref_id;
	}
	else if (WPHC_REFERENCE_ID != '') {
		return WPHC_REFERENCE_ID;
	}
	else {
		return '';
	}
}

function wphc_reference_id_check() {
	if (WPHC_REFERENCE_ID != '' && !get_option('wphc_reference_id')) {
		update_option('wphc_reference_id', WPHC_REFERENCE_ID);
	}
}
if (is_admin()) {
	add_action('init', 'wphc_reference_id_check');
}

function wphc_request_handler() {
	if (!empty($_GET['cf_action'])) {
		switch ($_GET['cf_action']) {
			case 'wphc_admin_js':
				wphc_admin_js();
				break;
			case 'wphc_admin_css':
				wphc_admin_css();
				die();
				break;
			case 'wphc_system_profile':
				if (current_user_can('manage_options') || wphc_info_page_token_check($_GET['token'])) {
					wphc_info_page();
				}
				else {
					wphc_denied_page();
				}
				die();
				break;
		}
	}
	if (!empty($_POST['cf_action'])) {
		switch ($_POST['cf_action']) {
			case 'wphc_request_call':
				wphc_request_call();
				die();
				break;
			case 'wphc_send_info':
				wphc_send_info();
				die();
				break;
		}
	}
}
add_action('init', 'wphc_request_handler', 999);

function wphc_request_call() {
	$user = wp_get_current_user();
	(empty($user->first_name) && empty($user->last_name)) ? $user_name = $user->display_name : $user_name = $user->first_name.' '.$user->last_name;
	$user_email = $user->user_email;
	if (!empty($_POST['info'])) {
		wphc_info_page_token_set();
		$url = __('System Profile:', 'wphelpcenter')."\n\n  ".wphc_info_page_url();
	}
	else {
		$url = '';
	}
	if ($_POST['calltime'] == 'ASAP') {
		$calltime = __('ASAP', 'wphelpcenter');
	}
	else {
		$calltime = stripslashes($_POST['calltime_at']);
	}
	$body = '
'.__('WordPress HelpCenter Call Request', 'wphelpcenter').'

============================================


'.__('From:            ', 'wphelpcenter').$user_name.'

'.__('Email:           ', 'wphelpcenter').$user_email.'

'.__('Phone:           ', 'wphelpcenter').stripslashes($_POST['phone']).'

'.__('Call at:         ', 'wphelpcenter').$calltime.' '.sprintf(__('(detected time zone: %s)', 'wphelpcenter'), stripslashes($_POST['timezone'])).'

'.__('Browser:         ', 'wphelpcenter').$_SERVER['HTTP_USER_AGENT'].'

'.$url.'


============================================
	';
	wp_mail(WPHC_EMAIL, __('Call Request from ', 'wphelpcenter').$user_name, $body, 'From: "'.$user_name.'" <'.$user_email.'>');
?>
<div class="response">
	<p><?php _e('<b>Thank you</b> for your request to WordPress HelpCenter. We will call as close to your requested time as possible.', 'wphelpcenter'); ?></p>
	<p><a href="#" class="button"><?php _e('OK', 'wphelpcenter'); ?></a></p>
</div>
<?php
	die();
}

function wphc_send_info() {
	$user = wp_get_current_user();
	(empty($user->first_name) && empty($user->last_name)) ? $user_name = $user->display_name : $user_name = $user->first_name.' '.$user->last_name;
	$user_email = $user->user_email;
	wphc_info_page_token_set();
	$body = '
'.__('WordPress HelpCenter System Profile', 'wphelpcenter').'

============================================


'.__('From:            ', 'wphelpcenter').$user_name.'

'.__('Email:           ', 'wphelpcenter').$user_email.'

'.__('Browser:         ', 'wphelpcenter').$_SERVER['HTTP_USER_AGENT'].'

'.__('System Profile:', 'wphelpcenter')."\n\n  ".wphc_info_page_url().'


============================================
	';
	wp_mail(WPHC_EMAIL, __('System Profile from ', 'wphelpcenter').$user_name, $body, 'From: "'.$user_name.'" <'.$user_email.'>');
?>
<div class="response">
	<p><?php _e('<b>Thank you.</b> Information about your WordPress installation has been sent to WordPress HelpCenter. <br /> <span class="small">Keep this plugin active to make your System Profile available.</span>', 'wphelpcenter'); ?></p>
	<p><a href="#" class="button"><?php _e('OK', 'wphelpcenter'); ?></a></p>
</div>
<?php
	die();
}

wp_enqueue_script('jquery');

function wphc_admin_js() {
	header('Content-type: text/javascript');
?>
wphc = {}
wphc.timezone = function() {
	var timezone = (new Date().getTimezoneOffset()/60)*(-1);
	return timezone;
}
wphc.loading = function() {
	return '<div class="loading"><span><?php _e('Loading...', 'wphelpcenter'); ?></span></div>';
}

jQuery(function($) {
	$('body').append('<?php echo str_replace("'", "\'", wphc_tab()); ?>');
	$('#wphc_tab a.tab').click(function() {
		$('#wphc_tab div.content').slideToggle('fast', function() {
			if ($.browser.msie && $.browser.version == 6) {
				if ($(this).is(':visible')) {
					$('select').css('visibility', 'hidden');
				}
				else {
					$('select').css('visibility', 'visible');
				}
			}
		});
		return false;
	});
	$('#wphc_tab .inner .footer a, #wphc_tab a.newwin').click(function() {
		window.open($(this).attr('href'));
		return false;
	});
	$('#wphc_tab #wphc_call_form_toggle, #wphc_phone_cancel').unbind().click(function() {
		$('#wphc_tab #wphc_call_form').slideToggle('fast', function() {
			$('#wphc_tab #wphc_phone:visible').focus();
		});
		return false;
	});
	$('#wphc_tab #wphc_info_form_toggle, #wphc_info_cancel').unbind().click(function() {
		$('#wphc_tab #wphc_info_form').slideToggle('fast');
		return false;
	});
	$('#wphc_calltime_at_time').click(function() {
		$('#wphc_calltime_at').attr('checked', true);
	});
	$('#wphc_call_form').submit(function() {
		var form = $(this);
		var phone = $('#wphc_phone');
		if (phone.val() == '') {
			alert('Please enter your phone number.');
			phone.css('background', '#ffc').focus();
			return false;
		}
		$(this).hide();
		var target = $('#wphc_call_form_response');
		target.html(wphc.loading()).show();
		$.post(
			'<?php echo bloginfo('url'); ?>/index.php',
			{
				cf_action: 'wphc_request_call',
				phone: phone.val(),
				calltime: $(this).find('input[name=wphc_calltime]:checked').val(),
				calltime_at: $('#wphc_calltime_at_time').val(),
				timezone: wphc.timezone(), 
				info: $('#wphc_call_info').val()
			},
			function(response) {
				target.html(response);
				$('#wphc_call_form_response a.button').click(function() {
					target.slideUp();
					return false;
				});
			}
		);
		return false;
	});
	$('#wphc_info_form').submit(function() {
		var form = $(this);
		$(this).hide();
		var target = $('#wphc_info_form_response');
		target.html(wphc.loading()).show();
		$.post(
			'<?php echo bloginfo('url'); ?>/index.php',
			{
				cf_action: 'wphc_send_info',
				timezone: wphc.timezone() 
			},
			function(response) {
				target.html(response);
				$('#wphc_info_form_response a.button').click(function() {
					target.slideUp();
					return false;
				});
			}
		);
		return false;
	});
	if ($.browser.msie && $.browser.version == 6) {
		$('#wphc_tab div.inner').append('<div class="clear ie6shim" style="height: 1px; overflow: hidden;">&nbsp;</div>');
	}
});
<?php
	die();
}
if (is_admin() && !in_array(basename($_SERVER['SCRIPT_FILENAME']), array('theme-install.php', 'plugin-install.php', 'media-upload.php', 'update.php'))) {
	wp_enqueue_script('wphc_admin_js', trailingslashit(get_bloginfo('url')).'?cf_action=wphc_admin_js', array('jquery'));
}

function wphc_admin_css() {
	header('Content-type: text/css');
?>
fieldset.options div.option {
	background: #EAF3FA;
	margin-bottom: 8px;
	padding: 10px;
}
fieldset.options div.option label {
	display: block;
	float: left;
	font-weight: bold;
	margin-right: 10px;
	width: 150px;
}
fieldset.options div.option span.help {
	color: #666;
	font-size: 11px;
	margin-left: 8px;
}
#wphc_tab {
	left: 50%;
	margin-left: -225px;
	position: absolute;
	overflow: hidden;
	text-align: center;
	top: 0;
	width: 450px;
	z-index: 999;
}
#wphc_tab div.content {
	background: #8c8c8c;
	border-radius-bottom-left: 6px;
	border-radius-bottom-right: 6px;
	-moz-border-radius-bottomleft: 6px;
	-moz-border-radius-bottomright: 6px;
	-webkit-border-radius-bottom-left: 6px;
	-webkit-border-radius-bottom-right: 6px;
	display: none;
	padding: 0 6px 6px;
}
#wphc_tab div.content div.inner {
	background: #fff;
	border-radius-bottom-left: 3px;
	border-radius-bottom-right: 3px;
	-moz-border-radius-bottomleft: 3px;
	-moz-border-radius-bottomright: 3px;
	-webkit-border-radius-bottom-left: 3px;
	-webkit-border-radius-bottom-right: 3px;
	text-align: left;
}
#wphc_tab div.content div.inner ul {
	margin-bottom: 10px;
}
#wphc_tab div.content div.inner p, #wphc_tab div.content div.inner li {
	margin: 0;
	padding: 0 10px 10px;
}
#wphc_tab #wphc_call_form_toggle, #wphc_tab #wphc_info_form_toggle {
	font-weight: bold;
}
#wphc_tab div.content div.inner li {
	padding: 0 10px 5px 15px;
}
#wphc_tab div.content div.inner p.intro {
	font-size: 14px;
	padding: 10px;
	text-align: center;
}
#wphc_tab div.content div.inner p.info {
	font-size: 11px;
}
#wphc_tab div.content div.inner div.contact {
	background: #8c8c8c;
	color: #fff;
	margin: 0 0 10px;
}
#wphc_tab div.content div.inner p.contact {
	font: 22px Georgia,"Times New Roman","Bitstream Charter",Times,serif;
	padding: 10px;
	text-align: center;
}
#wphc_tab div.content div.inner p.contact span {
	display: block;
	font-size: 16px;
}
#wphc_tab div.content div.inner p.contact span a, 
#wphc_tab div.content div.inner p.contact span a:visited {
	color: #fff;
}
#wphc_tab div.content div.inner div.contact p.reference-code {
	font-size: 11px;
	text-align: center;
}
#wphc_tab div.content div.inner div.contact p.reference-code b {
	background: #797979;
	font: bold 14px "Courier New", monospace;
	padding: 3px 5px;
}
#wphc_tab div.content div.inner form {
	display: none;
	zoom: 1;
}
#wphc_tab div.content div.inner form input.text {
	font-size: 12px;
	padding: 1px;
}
#wphc_tab div.content div.inner .response {
	background: #dfdfdf;
	margin: 0 10px 10px;
	padding: 10px;
	text-align: center;
}
#wphc_tab div.content div.inner .response p {
	font-size: 14px;
}
#wphc_tab div.content div.inner .response p span.small {
	display: block;
	font-size: 11px;
	margin-top: 5px;
}
#wphc_tab div.content .loading {
	background: url(<?php bloginfo('wpurl'); ?>/<?php echo PLUGINDIR; ?>/wphelpcenter/img/spinner.gif) 10px 13px no-repeat;
	clear: both;
	color: #ccc;
	height: 50px;
	margin-left: 10px;
}
#wphc_tab div.content .loading span {
	display: block;
	padding: 13px 32px 0;
}
#wphc_tab div.content div.inner p.footer {
	background: #dfdfdf;
	border-radius-bottom-left: 3px;
	border-radius-bottom-right: 3px;
	-moz-border-radius-bottomleft: 3px;
	-moz-border-radius-bottomright: 3px;
	-webkit-border-radius-bottom-left: 3px;
	-webkit-border-radius-bottom-right: 3px;
	font-size: 11px;
	margin: 0;
	padding: 8px;
	text-align: center;
}
#wphc_tab .ie6shim {
	background: #dfdfdf;
}
#wphc_tab a.tab {
	background: url(<?php bloginfo('wpurl'); ?>/<?php echo PLUGINDIR; ?>/wphelpcenter/img/tab-gray.png) no-repeat top center;
	display: block;
	height: 40px;
	margin: 0 auto;
	overflow: hidden;
	text-indent: -2000px;
	width: 230px;
}
#wphc-icon-32 {
	background: url(<?php bloginfo('wpurl'); ?>/<?php echo PLUGINDIR; ?>/wphelpcenter/img/wphc-lifering-32.png) no-repeat;
}
<?php
	if (wphc_color_scheme() == 'classic') {
		global $wp_version;
		if (version_compare($wp_version, '2.8', '>=')) {
			$tab_img = get_bloginfo('wpurl').'/'.PLUGINDIR.'/wphelpcenter/img/tab-blue-2.8.png';
			$bgcolor = '#336da0';
			$code_bgcolor = '#1d507d';
		}
		else {
			$tab_img = get_bloginfo('wpurl').'/'.PLUGINDIR.'/wphelpcenter/img/tab-blue.png';
			$bgcolor = '#195277';
			$code_bgcolor = '#195277';
		}
?>
#wphc_tab div.content, #wphc_tab div.content div.inner div.contact, #wphc_tab .ie6shim {
	background: <?php echo $bgcolor; ?>;
}
#wphc_tab div.content div.inner div.contact p.reference-code b {
	background: <?php echo $code_bgcolor; ?>;
}
#wphc_tab a.tab {
	background-image: url(<?php echo $tab_img; ?>);
}
#wphc_tab div.content div.inner .response, #wphc_tab div.content div.inner p.footer {
	background: #eaf3fa;
}
<?php
	}
	die();
}

function wphc_admin_head() {
	switch (wphc_color_scheme()) {
		case 'classic':
			global $wp_version;
			version_compare($wp_version, '2.8', '>=') ? $ie_img = get_bloginfo('wpurl').'/'.PLUGINDIR.'/wphelpcenter/img/tab-blue-2.8.gif' : 
$ie_img = get_bloginfo('wpurl').'/'.PLUGINDIR.'/wphelpcenter/img/tab-blue.gif';
			break;
		default:
			$ie_img = get_bloginfo('wpurl').'/'.PLUGINDIR.'/wphelpcenter/img/tab-gray.gif';
			break;
	}
	echo '
<link rel="stylesheet" type="text/css" href="'.trailingslashit(get_bloginfo('url')).'?cf_action=wphc_admin_css" />
<!--[if lt IE 7]>
<style type="text/css" media="screen">
#wphc_tab a.tab, #wphc_tab a.tab:hover {
	background-image: url('.$ie_img.');
	zoom: 1;
}
</style>
<![endif]-->
	';
}
add_action('admin_head', 'wphc_admin_head');

function wphc_color_scheme() {
	$user = wp_get_current_user();
	return get_usermeta($user->ID, 'admin_color');
}

function wphc_tab() {
	$sys_profile = get_bloginfo('wpurl').'/wp-admin/index.php?page='.basename(__FILE__);
	$output = '
<div id="wphc_tab">
	<div class="content">
		<div class="inner">
			<p class="intro">'.__('Your on-call resource for all things WordPress.', 'wphelpcenter').'</p>
			<div class="contact">
				<p class="contact">'.__('Call Us Now:', 'wphelpcenter').' '.WPHC_PHONE.'<span>'.__('or email:', 'wphelpcenter').' <a href="mailto:'.WPHC_EMAIL.'">'.WPHC_EMAIL.'</a></span></p>
	';
	if (wphc_reference_id() != '') {
		$output .= '
				<p class="reference-code">'.sprintf(__('Please provide code: <b>%s</b>', 'wphelpcenter'), wphc_reference_id()).'</p>
		';
	}
	$output .= '
			</div>
			<p>'.__('We can help with everything from plugins to themes, installation to configuration, customization and hosting.', 'wphelpcenter').'</p>
			<p><a href="#" id="wphc_call_form_toggle">'.__("I'd like someone to call me", 'wphelpcenter').'</a></p>
			<form action="$wp_url" method="post" id="wphc_call_form">
				<p>
					<label for="wphc_phone">'.__('My Phone #:', 'wphelpcenter').'</label> 
					<input type="text" name="wphc_phone" id="wphc_phone" value="" class="text" />
				</p>
				<p>
					<label>'.__('Please Call:', 'wphelpcenter').'</label>
					<ul class="options">
						<li>
							<input type="radio" name="wphc_calltime" id="wphc_calltime_asap" value="ASAP" checked="checked" /> 
							<label for="wphc_calltime_asap">'.__('As soon as possible!', 'wphelpcenter').'</label>
						</li>
						<li>
							<input type="radio" name="wphc_calltime" id="wphc_calltime_at" value="at" /> 
							<label for="wphc_calltime_at">'.__('At this time:', 'wphelpcenter').'</label> 
							<input type="text" name="wphc_calltime_at_time" id="wphc_calltime_at_time" value="" class="text" /> 
						</li>
					</ul>
				</p>
				<p>
					<input type="checkbox" name="wphc_call_info" id="wphc_call_info" value="1" checked="checked" /> 
					<label for="wphc_call_info">'.sprintf(__('Include my <a href="%s" class="newwin">System Profile</a> for troubleshooting purposes', 'wphelpcenter'), $sys_profile).'</label>
				</p>
				<p>
					<input type="submit" name="wphc_phone_submit" id="wphc_phone_submit" value="'.__('Please Call Me', 'wphelpcenter').'" class="button-primary" /> 
					or <a href="#" id="wphc_phone_cancel">Cancel</a>
				</p>
				<input type="hidden" name="cf_action" id="cf_action" value="wphc_request_call" />
			</form>
			<div id="wphc_call_form_response"></div>
			<p><a href="#" id="wphc_info_form_toggle">'.__('Send System Profile to WordPress HelpCenter', 'wphelpcenter').'</a></p>
			<form action="'.get_bloginfo('wpurl').'/index.php" method="post" id="wphc_info_form">
				<p class="info">'.sprintf(__('This will send your <a href="%s" class="newwin">System Profile</a> details to WordPress HelpCenter. This information may be useful for troubleshooting, answering questions, etc.', 'wphelpcenter'), $sys_profile).'</p>
				<p>
					<input type="submit" name="wphc_info_submit" id="wphc_info_submit" value="'.__('Send Information', 'wphelpcenter').'" class="button-primary" />
					 or <a href="#" id="wphc_info_cancel">'.__('Cancel', 'wphelpcenter').'</a>
				</p>
				<input type="hidden" name="cf_action" id="cf_action_info" value="wphc_send_info" />
			</form>
			<div id="wphc_info_form_response"></div>
			<p class="footer">'.__('Available 9am-5pm <a href="http://timeanddate.com/worldclock/fixedtime.html?month=1&amp;day=1&amp;year=2009&amp;hour=9&amp;min=0&amp;sec=0&amp;p1=224">US/Pacific</a>. Visit the <a href="http://wphelpcenter.com">WordPress HelpCenter web site</a> for our price list and <a href="http://wphelpcenter.com/tos/">terms of service</a>.', 'wphelpcenter').'</p>
		</div>
		<div class="clear"></div>
	</div>
	<a href="http://wphelpcenter.com" class="tab">WordPress HelpCenter</a>
</div>
	';
	$output = str_replace(array("\t", "\n"), '', $output);
	return $output;
}

function wphc_info_page_token_set() {
	$token = md5(microtime().get_bloginfo('url')).'_'.date('Ymd', strtotime('+3 days'));
	if (get_option('wphc_info_page_token') == '') {
		add_option('wphc_info_page_token', $token);
	}
	else {
		update_option('wphc_info_page_token', $token);
	}
}

function wphc_info_page_token_get() {
	$token = get_option('wphc_info_page_token');
	if (empty($token)) {
		return false;
	}
	$token = explode('_', $token);
	return $token[0];
}

function wphc_info_page_token_check($token = 'example') {
// check date
	$key = get_option('wphc_info_page_token');
	$date = explode('_', $key);
	$date = $date[1];
	if (intval($date) < intval(date('Ymd'))) {
		return false;
	}
// check token
	return (wphc_info_page_token_get() == $token);
}

function wphc_info_page_url() {
	return get_bloginfo('url').'/index.php?cf_action=wphc_system_profile&token='.wphc_info_page_token_get();
}

function wphc_info_page() {
	wp_enqueue_script('jquery');
	get_header();
	wphc_info_page_content();
	get_footer();
}

function wphc_info_page_content() {
	include_once(ABSPATH.'/wp-admin/includes/plugin.php');
	include_once(ABSPATH.'/wp-admin/includes/theme.php');
	global $wp_version;
	version_compare('2.7', $wp_version, '<=') ? $icon = '<div id="wphc-icon-32" class="icon32"><br /></div>' : $icon = '';
	print('
<script type="text/javascript">
jQuery(function($) {
	$("#wphc_info table").each(function() {
		$(this).find("tr:even").addClass("alt");
		$(this).find("tr td:first").css("width", "200px");
	});
});
</script>
<style type="text/css">
#wphc_info {
	text-align: left;
}
#wphc_info table {
	margin-bottom: 20px;
	width: 95%;
}
#wphc_info table tr.alt td {
	background: #eee;
}
#wphc_info table td {
	padding: 5px;
	vertical-align: top;
}
</style>
<div class="wrap" id="wphc_info">
	'.$icon.'
	<h2>'.__('WordPress HelpCenter System Profile', 'wphelpcenter').'</h2>
	<h3>'.__('Server Environment', 'wphelpcenter').'</h3>
	<table>
		<tbody>
			<tr>
				<td>'.__('PHP Version', 'wphelpcenter').'</td>
				<td>'.phpversion().'</td>
			</tr>
			<tr>
				<td>'.__('PHP Extensions', 'wphelpcenter').'</td>
				<td>'.implode(', ', get_loaded_extensions()).'</td>
			</tr>
			<tr>
				<td>'.__('MySQL Version', 'wphelpcenter').'</td>
				<td>'.mysql_get_server_info().'</td>
			</tr>
			<tr>
				<td>'.__('Web Server', 'wphelpcenter').'</td>
				<td>'.$_SERVER['SERVER_SOFTWARE'].'</td>
			</tr>
		</tbody>
	</table>
	');
	global $wpmu_version, $wp_version;
	is_null($wpmu_version) ? $wp_type = __('WordPress (single user)', 'wphelpcenter') : $wp_type = __('WordPress MU', 'wphelpcenter');
	// adapted from wp-admin/plugins.php, WP 2.7
	$all_plugins = get_plugins();
	$active_plugins = array();
	$inactive_plugins = array();
	foreach ( (array)$all_plugins as $plugin_file => $plugin_data) {
		//Filter into individual sections
		if ( is_plugin_active($plugin_file) ) {
			$active_plugins[ $plugin_file ] = $plugin_data;
		} else {
			$inactive_plugins[ $plugin_file ] = $plugin_data;
		}
	}
	// adapted from wp-admin/themes.php, WP 2.7
	$themes = get_themes();
	$ct = current_theme_info();
	$sidebar_widgets = '';
	$current_sidebar = '';
	$active_widgets = get_option('sidebars_widgets');
	if (is_array($active_widgets) && count($active_widgets)) {
		foreach ($active_widgets as $sidebar => $widgets) {
			if (is_array($widgets)) {
				if ($sidebar != $current_sidebar) {
					$sidebar_widgets .= '<strong>'.$sidebar.':</strong> ';
					$current_sidebar = $sidebar;
				}
				if (count($widgets)) {
					$sidebar_widgets .= implode(', ', $widgets);
				}
				else {
					$sidebar_widgets .= __('(none)', 'wphelpcenter');
				}
				$sidebar_widgets .= '<br />';
			}
		}
	}
	get_option('permalink_structure') == '' ? $permalinks = __('Query String (index.php?p=123)', 'wphelpcenter') : $permalinks = __('Pretty Permalinks', 'wphelpcenter');
	get_option('users_can_register') == '1' ? $reg = __('Yes', 'wphelpcenter') : $reg = __('No', 'wphelpcenter');
	get_option('enable_xmlrpc') == '1' ? $xmprpc = __('Yes', 'wphelpcenter') : $xmprpc = __('No', 'wphelpcenter');
	get_option('enable_app') == '1' ? $atompub = __('Yes', 'wphelpcenter') : $atompub = __('No', 'wphelpcenter');
	get_option('blog_public') == '1' ? $privacy = __('Public', 'wphelpcenter') : $privacy = __('Private', 'wphelpcenter');
	get_option('rss_use_excerpt') == '1' ? $feed = __('Summaries', 'wphelpcenter') : $feed = __('Full Content', 'wphelpcenter');
	print('
	<h3>'.__('WordPress Environment', 'wphelpcenter').'</h3>
	<table>
		<tbody>
			<tr>
				<td>'.__('Type', 'wphelpcenter').'</td>
				<td>'.$wp_type.'</td>
			</tr>
			<tr>
				<td>'.__('Version', 'wphelpcenter').'</td>
				<td>'.$wp_version.'</td>
			</tr>
			<tr>
				<td>'.__('File Path', 'wphelpcenter').'</td>
				<td>'.ABSPATH.'</td>
			</tr>
			<tr>
				<td>'.__('Site URL', 'wphelpcenter').'</td>
				<td>'.get_bloginfo('url').'</td>
			</tr>
			<tr>
				<td>'.__('WordPress URL', 'wphelpcenter').'</td>
				<td>'.get_bloginfo('wpurl').'</td>
			</tr>
			<tr>
				<td>'.__('Permalink Type', 'wphelpcenter').'</td>
				<td>'.$permalinks.'</td>
			</tr>
			<tr>
				<td>'.__('Registration Enabled', 'wphelpcenter').'</td>
				<td>'.$reg.'</td>
			</tr>
			<tr>
				<td>'.__('XML-RPC Enabled', 'wphelpcenter').'</td>
				<td>'.$xmprpc.'</td>
			</tr>
			<tr>
				<td>'.__('Atom Pub Enabled', 'wphelpcenter').'</td>
				<td>'.$atompub.'</td>
			</tr>
			<tr>
				<td>'.__('Privacy Settings', 'wphelpcenter').'</td>
				<td>'.$privacy.'</td>
			</tr>
			<tr>
				<td>'.__('Feed Content', 'wphelpcenter').'</td>
				<td>'.$feed.'</td>
			</tr>
			<tr>
				<td>'.__('Active Plugins', 'wphelpcenter').'</td>
				<td>
					<ul>
	');
	foreach ( (array)$active_plugins as $plugin_file => $plugin_data) {
		print('
						<li><strong>'.wp_specialchars($plugin_data['Title']).'</strong> &mdash; '.__('version:', 'wphelpcenter').' '.wp_specialchars($plugin_data['Version']).'</li>
		');
	}
	print('
					</ul>
				</td>
			</tr>
			<tr>
				<td>'.__('Inactive Plugins', 'wphelpcenter').'</td>
				<td>
					<ul>
	');
	foreach ( (array)$inactive_plugins as $plugin_file => $plugin_data) {
		print('
						<li><strong>'.wp_specialchars($plugin_data['Title']).'</strong> &mdash; '.__('version:', 'wphelpcenter').' '.wp_specialchars($plugin_data['Version']).'</li>
		');
	}
	print('
					</ul>
				</td>
			</tr>
			<tr>
				<td>'.__('Current Theme', 'wphelpcenter').'</td>
				<td>'.sprintf(_c('%1$s %2$s by %3$s|1: theme title, 2: theme version, 3: theme author'), $ct->title, $ct->version, $ct->author).'</td>
			</tr>
			<tr>
				<td>'.__('Sidebars / Widgets', 'wphelpcenter').'</td>
				<td>'.$sidebar_widgets.'</td>
			</tr>
		</tbody>
	</table>
</div>
	');
	do_action('wphc_info_page_content');
}

function wphc_denied_page() {
	wp_die(__('Sorry, your System Profile token has expired or is invalid. Please request a new one.', 'wphelpcenter'));
}

function wphc_admin_menu() {
	if (current_user_can('manage_options')) {
		add_submenu_page(
			'index.php',
			__('System Profile', 'wphelpcenter'), 
			__('System Profile', 'wphelpcenter'), 
			10, 
			basename(__FILE__), 
			'wphc_info_page_content'
		);
	}
}
add_action('admin_menu', 'wphc_admin_menu');

//a:21:{s:11:"plugin_name";s:20:"WordPress HelpCenter";s:10:"plugin_uri";s:23:"http://wphelpcenter.com";s:18:"plugin_description";s:76:"Easily contact WordPress HelpCenter for questions, etc. regarding WordPress.";s:14:"plugin_version";s:3:"1.0";s:6:"prefix";s:4:"wphc";s:12:"localization";s:12:"wphelpcenter";s:14:"settings_title";s:20:"WordPress HelpCenter";s:13:"settings_link";s:20:"WordPress HelpCenter";s:4:"init";b:0;s:7:"install";b:0;s:9:"post_edit";b:0;s:12:"comment_edit";b:0;s:6:"jquery";s:1:"1";s:6:"wp_css";b:0;s:5:"wp_js";b:0;s:9:"admin_css";s:1:"1";s:8:"admin_js";s:1:"1";s:15:"request_handler";s:1:"1";s:6:"snoopy";b:0;s:11:"setting_cat";b:0;s:14:"setting_author";b:0;}

endif; // loaded check

?>